@@ -33,7 +33,7 @@ from asyncio.runners import _cancel_all_tasks  # type: ignore[attr-defined]
 from base64 import b64encode
 from collections.abc import Callable, Coroutine, Iterable
 from configparser import ConfigParser
-from hashlib import sha256
+from hashlib import sha3_512, sha256
 from multiprocessing import process
 from pathlib import Path
 from typing import Any, Final, cast
@@ -425,6 +425,10 @@ def apply_config_to_app(app: Application, config: BetterConfigParser) -> None:
         if (key_perms := [part.strip() for part in secret.split("=")])
         if key_perms[0]
     }
+    app.settings["AUTH_TOKEN_SECRET"] = (
+        config.get("GENERAL", "AUTH_TOKEN_SECRET", fallback=None)
+        or sha3_512(__file__.encode("UTF-8")).digest()
+    )
 
     app.settings["UNDER_ATTACK"] = config.getboolean(
         "GENERAL", "UNDER_ATTACK", fallback=False
@@ -549,6 +553,9 @@ def setup_apm(app: Application) -> None:  # pragma: no cover
         "SERVER_URL": config.get(
             "ELASTIC_APM", "SERVER_URL", fallback="http://localhost:8200"
         ),
+        "SERVER_URL_JS_AGENT": config.get(
+            "ELASTIC_APM", "SERVER_URL_JS_AGENT", fallback=None
+        ),
         "SECRET_TOKEN": config.get(
             "ELASTIC_APM", "SECRET_TOKEN", fallback=None
         ),
@@ -578,14 +585,31 @@ def setup_apm(app: Application) -> None:  # pragma: no cover
             "elasticapm.processors.sanitize_http_wsgi_env",
             "elasticapm.processors.sanitize_http_request_body",
         ],
+        "SERVER_URL_PREFIX": config.get(
+            "ELASTIC_APM", "SERVER_URL_PREFIX", fallback=None
+        ),
     }
+    script_options = [
+        f"serviceName:'{app.settings['ELASTIC_APM']['SERVICE_NAME']}'",
+        f"serviceVersion:'{app.settings['ELASTIC_APM']['SERVICE_VERSION']}'",
+        f"environment:'{app.settings['ELASTIC_APM']['ENVIRONMENT']}'",
+    ]
+    server_url_js_agent = app.settings["ELASTIC_APM"]["SERVER_URL_JS_AGENT"]
+    if server_url_js_agent is None:
+        script_options.append(
+            f"serverUrl:'{app.settings['ELASTIC_APM']['SERVER_URL']}'"
+        )
+    elif server_url_js_agent:
+        script_options.append(f"serverUrl:'{server_url_js_agent}'")
+    else:
+        script_options.append("serverUrl:window.location.origin")
+
+    if app.settings["ELASTIC_APM"]["SERVER_URL_PREFIX"]:
+        script_options.append(
+            f"serverUrlPrefix:'{app.settings['ELASTIC_APM']['SERVER_URL_PREFIX']}'"
+        )
     app.settings["ELASTIC_APM"]["INLINE_SCRIPT"] = (
-        "elasticApm.init({"
-        f"serverUrl:'{app.settings['ELASTIC_APM']['SERVER_URL']}',"
-        f"serviceName:'{app.settings['ELASTIC_APM']['SERVICE_NAME']}',"
-        f"serviceVersion:'{app.settings['ELASTIC_APM']['SERVICE_VERSION']}',"
-        f"environment:'{app.settings['ELASTIC_APM']['ENVIRONMENT']}',"
-        "})"
+        "elasticApm.init({" + ",".join(script_options) + "})"
     )
     app.settings["ELASTIC_APM"]["INLINE_SCRIPT_HASH"] = b64encode(
         sha256(
